@@ -4,12 +4,12 @@ from pymongo.database import Database
 from pymongo import MongoClient
 from pymongo.results import InsertOneResult
 from typing import Union, Callable, Optional, Type
-from datetime import datetime
+from datetime import datetime, timedelta
 from .job import Job
 from .misc import parse_time_to_seconds, toOid
 
 class Queue:
-  def __init__(self, connection: Union[str, Type[Collection], Type[Database], Type[MongoClient]], consumerId: str = "default-customer-id", lang: str = "python", channel: str = "default", priority: int = 0, job_timeout: Union[str, int, None]='1h', result_ttl: Union[str,int,None]=500, ttl: Union[str,int,None]=None, failure_ttl: Union[str,int]='1y', max_attempts: int=1, db_name: Optional[str]="jobs", col_name: Optional[str]="jobs") -> None:
+  def __init__(self, connection: Union[str, Type[Collection], Type[Database], Type[MongoClient]], consumerId: str = "default-customer-id", lang: str = "python", channel: str = "default", priority: int = 0, job_timeout: Union[str, int, None]='1h', result_ttl: Union[str,int,None]=3600, ttl: Union[str,int,None]=None, failure_ttl: Union[str,int]='1w', max_attempts: int=1, db_name: Optional[str]="jobs", col_name: Optional[str]="jobs") -> None:
     
     if isinstance(connection, MongoClient):
       db = connection[db_name]
@@ -30,7 +30,7 @@ class Queue:
     self.max_attempts = max_attempts
     self.channel = channel
     self.result_ttl = parse_time_to_seconds(result_ttl) if not result_ttl is None else result_ttl
-    self.ttl = ttl = parse_time_to_seconds(ttl) if not ttl is None else ttl
+    self.ttl = parse_time_to_seconds(ttl) if not ttl is None else ttl
     self.failure_ttl = parse_time_to_seconds(failure_ttl) if not failure_ttl is None else failure_ttl
     self.priority = priority
 
@@ -117,9 +117,13 @@ class Queue:
       "progress": 0,
       "priority": priority,
       "lang": lang,
-      "createdAt": datetime.utcnow()
+      "createdAt": datetime.utcnow(),
     }
 
+    if not (ttl is None):
+      if int(ttl) > 0:
+        data["expireAt"] = datetime.utcnow() + timedelta(seconds=int(ttl))
+
     if not job_id is None:
       data["_id"] = toOid(job_id)
 
